==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/IPBUYVENDORID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour IPBUYVENDORID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="IPBUYVENDORID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IPVENDORCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IPBUYVENDORDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "IPBUYVENDORID_Type", propOrder = {
    "ipvendorcode",
    "organizationid",
    "ipbuyvendordescription"
})
public class IPBUYVENDORID_Type {

    @XmlElement(name = "IPVENDORCODE", required = true)
    protected QUANTITY ipvendorcode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "IPBUYVENDORDESCRIPTION")
    protected String ipbuyvendordescription;

    /**
     * Obtient la valeur de la propriété ipvendorcode.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getIPVENDORCODE() {
        return ipvendorcode;
    }

    /**
     * Définit la valeur de la propriété ipvendorcode.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setIPVENDORCODE(QUANTITY value) {
        this.ipvendorcode = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété ipbuyvendordescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIPBUYVENDORDESCRIPTION() {
        return ipbuyvendordescription;
    }

    /**
     * Définit la valeur de la propriété ipbuyvendordescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIPBUYVENDORDESCRIPTION(String value) {
        this.ipbuyvendordescription = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/IPBUYVENDORID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for IPBUYVENDORID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="IPBUYVENDORID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IPVENDORCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IPBUYVENDORDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "IPBUYVENDORID_Type", propOrder = {
    "ipvendorcode",
    "organizationid",
    "ipbuyvendordescription"
})
public class IPBUYVENDORID_Type {

    @XmlElement(name = "IPVENDORCODE", required = true)
    protected QUANTITY ipvendorcode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "IPBUYVENDORDESCRIPTION")
    protected String ipbuyvendordescription;

    /**
     * Gets the value of the ipvendorcode property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getIPVENDORCODE() {
        return ipvendorcode;
    }

    /**
     * Sets the value of the ipvendorcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setIPVENDORCODE(QUANTITY value) {
        this.ipvendorcode = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the ipbuyvendordescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIPBUYVENDORDESCRIPTION() {
        return ipbuyvendordescription;
    }

    /**
     * Sets the value of the ipbuyvendordescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIPBUYVENDORDESCRIPTION(String value) {
        this.ipbuyvendordescription = value;
    }

}
